@@ -489,6 +489,21 @@ class InfluxUtil:
             json_data_list.append(json_data)
         cls.CONN.write_points(json_data_list)
 
+    @classmethod
+    def write_points(cls, conf: dict, json_data_list: list):
+        """向influxdb写入数据
+        :json_data_list 格式：[{
+            'measurement': 'tbl',
+            'time': time.replace(' ', 'T') + '+08:00',
+            'tags': {
+                'k': 'v'
+            },
+            'fields': {'k': 'v'},
+        }, ...]
+        """
+        cls._init(conf)
+        cls.CONN.write_points(json_data_list)
+
     @classmethod
     def create_db(cls, conf: dict, db_name: str):
         cls._init(conf)
